% Latexklasse LIV in Anlehnung an die LNI Klasse
% by Martin Gebauer gebauer@informatik.uni-leipzig.de, Stefan Kuehne kuehne@informatik.uni-leipzig.de (sk)
% 
\ProvidesClass{../0000_literaturquellen/liv}
\newif\ifpdf\ifx\pdfoutput\undefined\pdffalse\else\pdfoutput=1\pdftrue\fi

\clubpenalty = 10000
\widowpenalty = 10000
\displaywidowpenalty = 10000

\ifpdf
\usepackage[activate]{pdfcprot}				% pdfcprot funktioniert nur mit pdflatex
\else
\fi

%\DeclareOption{forInclusion}{%
%  \setlength{\topmargin}{0mm}%
%  \setlength{\headheight}{0mm}%
%  \setlength{\headsep}{0mm}%
%  \setlength{\hoffset}{0mm}% 
%  \setlength{\voffset}{0mm}% 
%  \setlength{\oddsidemargin}{0mm}%
%  \setlength{\evensidemargin}{0mm}%
%  \setlength{\paperheight}{235mm}%
%  \setlength{\paperwidth}{165mm}
%  \ifpdf%
%    \setlength{\pdfpageheight}{235mm}%
%    \setlength{\pdfpagewidth}{165mm}%
%  \fi}
%
\newif\iflnienglish\lnienglishfalse
\DeclareOption{english}{\lnienglishtrue}

\ProcessOptions
% 10 pt
\LoadClass[10pt,fleqn,twoside]{article}
\RequirePackage[english,ngerman]{babel}
\RequirePackage{url} %% added by sk 20080818
\iflnienglish\selectlanguage{english}\def\bbl@main@language{english}\fi
% Blocksatz durch LaTeX-Default
% Satzspiegel

% Times als Grundschrift
\RequirePackage{times}
% Hyphenation
% Durch normale LaTeX-Parameter verhindert (\doublehyphendemerits)

%\usepackage{fancyhdr}

% Title: Kopie aus article.cls mit anderem \thispagestyle
\renewcommand\maketitle{\par
  \begingroup
    \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
    \def\@makefnmark{\rlap{\@textsuperscript{\normalfont\@thefnmark}}}%
    \long\def\@makefntext##1{\parindent 1em\noindent
            \hb@xt@1.8em{%
                \hss\@textsuperscript{\normalfont\@thefnmark}}##1}%
    \if@twocolumn
      \ifnum \col@number=\@ne
        \@maketitle
      \else
        \twocolumn[\@maketitle]%
      \fi
    \else
      \newpage
      \global\@topnum\z@   % Prevents figures from going at top of page.
      \@maketitle
    \fi
    \thispagestyle{empty}\@thanks
  \endgroup
  
  
  
  
  \setcounter{footnote}{0}%
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}
\def\@maketitle{%
  \newpage
  \null
  
%  gendert von Axel Hummel am 08.11.2009
%  \vskip 2em%
   \vspace{-1em}%
  \begin{center}%
  \let \footnote \thanks
    {\fontsize{14}{17}\fontseries{b}\selectfont \@title \par}%
    \vskip 1.5em%
    {\fontsize{10}{12}\selectfont
      \lineskip .5em%
      \begin{tabular}[t]{c}%
        \@author
      \end{tabular}\par}%
    \vskip 1\baselineskip%
  \end{center}%
  \par
  }

% Abstract
\renewenvironment*{abstract}{%
 \renewcommand{\abstractname}{Kurzfassung}
 \fontsize{9}{10}\selectfont
    \quotation\noindent{\bfseries \abstractname:}%
}{\endquotation}  

% berschriften
\renewcommand{\section}{\@startsection{section}{1}{\z@}%
  {2\baselineskip}{\baselineskip}{\fontsize{12}{14}\fontseries{b}\selectfont}}
\renewcommand{\subsection}{\@startsection{subsection}{2}{\z@}%
  {2\baselineskip}{\baselineskip}{\fontsize{10}{12}\fontseries{b}\selectfont}}
\renewcommand{\subsubsection}{\@startsection{subsubsection}{3}{\z@}%
  {2\baselineskip}{\baselineskip}{\fontsize{10}{8}\fontseries{b}\selectfont}}
% weitere nicht durch Formatvorlage geklrt

% keine seitennummern oh doch
\pagestyle{empty}

%\fancyhead[EL]{}
%\fancyhead[EC]{}
%\fancyhead[ER]{}
%\fancyhead[OL]{}
%\fancyhead[OC]{}
%\fancyhead[OR]{}
%\renewcommand\headrulewidth{0pt}
%\fancyfoot[EC]{}
%\fancyfoot[OC]{}
%\fancyfoot[EL]{\thepage}
%\fancyfoot[OR]{\thepage}

% Bildunterschriften
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  {\fontsize{9}{10}\selectfont
   \sbox\@tempboxa{#1: #2}%
  \ifdim \wd\@tempboxa >\hsize
    #1: #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi}
  \vskip\belowcaptionskip}

% gleichungen mit richtiger einrckung
% fleqn-Option oben
\setlength{\mathindent}{4ex}

% listings mit richtiger einrckung
\RequirePackage{verbatim}
\def\verbatim@processline{\hskip4ex\the\verbatim@line\par}

% Fussnoten mit 5cm Linie und richtiger Gre
\renewcommand\footnoterule{%
  \kern-3\p@
  \hrule\@width5cm
  \kern2.6\p@}
\renewcommand\@makefntext[1]{%
    \parindent 1em%
    \noindent
    %%changed SK: mit Leerzeichen zwischen Funoten-Zeichen und Funoten-Text
    %%orig: \hb@xt@1.8em{\hss\@makefnmark}{\fontsize{8}{9}\selectfont{~#1}}}
    \hb@xt@1.8em{\hss\@makefnmark}{\fontsize{8}{9}\selectfont{~#1}}}

% Gemutmate Absatzeinzge und Abstnde
\parindent0pt
\parskip 1ex plus0.5ex minus0.25ex
\flushbottom

% bibliography
\iflanguage{english}{\bibliographystyle{alphadin}}{\bibliographystyle{alphadin}}
\renewenvironment{thebibliography}[1]
     {%\def\refname{Literaturverzeichnis}
      \section*{\refname}%
      \bgroup\fontsize{9}{10}\selectfont
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist\egroup}

% Anpassung an die vorgegebenen Seitenmae des MDSD-Seminars
% durchgefhrt von Axel Hummel am 08.11.2009	  
	  
%\setlength{\topmargin}{15mm}%
\setlength{\topmargin}{52.5mm}%

\setlength{\headheight}{0mm}%
\setlength{\headsep}{0mm}%
\setlength{\hoffset}{-1in}% 
\setlength{\voffset}{-1in}% 

%\setlength{\oddsidemargin}{13.5mm}%
\setlength{\oddsidemargin}{37mm}%

%\setlength{\evensidemargin}{15.5mm}%
\setlength{\evensidemargin}{37mm}%

%\setlength{\paperheight}{235mm}%
%\setlength{\paperwidth}{165mm}%
\setlength{\paperheight}{297mm}%
\setlength{\paperwidth}{210mm}%


\ifpdf%
	%\setlength{\pdfpageheight}{235mm}%
	%\setlength{\pdfpagewidth}{165mm}%
	\setlength{\pdfpageheight}{297mm}%
	\setlength{\pdfpagewidth}{210mm}%
\fi
  
\setlength{\textheight}{192mm}
\setlength{\textwidth}{136mm}
